$(document).ready(function () {
	$.urlParam = function (name) {
		var results = new RegExp("[?&]" + name + "=([^&#]*)").exec(window.location.href);
		return results[1] || 0;
	};
	let leagueSn;
	let seasonSn;
	var navTemplate = $.templates("#navTemplate");
	var navTemplateData = {
		teamSn: $.urlParam("teamSn"),
	};
	let timeInMs = Date.now();

	$("#nav").html(navTemplate.render(navTemplateData));

	$.showShootingChartContent = function (stageSn) {
		var shootingChartJSON;
		let stageName = $("#stageList .active").text();
		if (stageSn !== undefined) {
			shootingChartJSON = `/basketball/jsons/teams/${$.urlParam(
				"teamSn"
			)}/${leagueSn}/${seasonSn}/${stageSn}/scoreandmiss.json`;
		} else {
			shootingChartJSON = `/basketball/jsons/teams/${$.urlParam("teamSn")}/${leagueSn}/${seasonSn}/scoreandmiss.json`;
		}
		$.ajax({
			url: shootingChartJSON,
			method: "GET",
			dataType: "json",
		})
			.done((data) => {
				var score = 0,
					miss = 0;
				$.each(data, function (i, gamePlayerRecord) {
					if (gamePlayerRecord.eventName == "score") {
						score++;
					}
					if (gamePlayerRecord.eventName == "miss") {
						miss++;
					}
				});
				var shootingChartTemplateData = {
					stageName: stageName,
					shootingPercentage: new Number((score / (score + miss)) * 100).toFixed(1),
					made: score,
					attempt: score + miss,
				};
				var shootingChartContent = "";
				var shootingChartTemplate = $.templates("#shootingChartTemplate");
				shootingChartContent += shootingChartTemplate.render(shootingChartTemplateData);
				$("#teamShootingChart").html(shootingChartContent);
			})
			.fail(() => {
				let score = 0,
					miss = 0;
				var shootingChartTemplateData = {
					stageName: stageName,
					shootingPercentage: 0,
					made: score,
					attempt: score + miss,
				};
				var shootingChartContent = "";
				var shootingChartTemplate = $.templates("#shootingChartTemplate");
				shootingChartContent += shootingChartTemplate.render(shootingChartTemplateData);
				$("#teamShootingChart").html(shootingChartContent);
			})
			.always(() => {
				drawCourt("#court", shootingChartJSON);
				drawPercentageCourt("#percentageCourt", shootingChartJSON);
			});
	};

	$.showStageList = function (team) {
		var stageListJSON = `/basketball/jsons/stages/${leagueSn}/${seasonSn}/stagelist.json`;
		$.getJSON(stageListJSON, function (data) {
			var defaultStage;
			$.each(data, function (i, stage) {
				if (stage.active == 1) {
					defaultStage = stage;
					return false;
				}
			});
			$("#stageList").html("");
			$("#stageList").append('<div class="gameSight active">全學年度</div>');
			$.each(data, function (i, stage) {
				var stageOption = `<div class="gameSight" data-sn="${stage.sn}">${stage.name}</option>`;
				if (stage.gender == team.gender) {
					$("#stageList").append(stageOption);
				}
			});
		});
	};

	$.showTeamContent = function (teamSn) {
		let team;
		$.getJSON("/basketball/jsons/teams/" + teamSn + "/team.json", function (data) {
			team = data;
			leagueSn = team.season.league.sn;
			seasonSn = team.season.sn;
			let leagueName = "";
			switch (leagueSn) {
				case 1:
					leagueName = "高中甲組";
					break;
				case 2:
					leagueName = "國中甲組";
					break;
				case 3:
					leagueName = "高中乙組";
					break;
			}
			var teamTemplate = $.templates("#teamTemplate");
			var teamTemplateData = {
				teamLogo: team.logo + `?nocache=${timeInMs}`,
				teamName: team.name,
				leagueName: leagueName,
			};
			$("#teamInfo").html(teamTemplate.render(teamTemplateData));
		}).always(function () {
			$.showStageList(team);
			$.showShootingChartContent();
		});
	};

	// $("").change(function () {
	// 	var seasonSn = $("#seasonNum").val();
	// 	$.showSeasonList(defaultLeagueSn, seasonSn);
	// });
	$.showTeamContent($.urlParam("teamSn"));

	$("#stageList").on("click", ".gameSight", function () {
		$("#stageList .active").removeClass("active");
		$(this).addClass("active");
		let stageSn = $(this).data("sn");
		$.showShootingChartContent(stageSn);
	});

	var M_PI = 3.14159265358979323846264338327950288,
		M_PI_2 = 1.57079632679489661923132169163975144;
	var w = 2465,
		h = 1360;

	function degToRad(degree) {
		return (degree / 180) * M_PI;
	}

	function drawCourt(courtId, playerShootingChartJSON) {
		var c = $(courtId);
		var ctx = c[0].getContext("2d");
		var hoop = document.getElementById("hoop");

		var startX = 40,
			startY = 40,
			METER_RATIO = 85;
		var endLineToArc = 1.415 + 1.575;
		var degree = 12.101;

		// 轉90度
		ctx.translate(h, 0);
		ctx.rotate((90 * Math.PI) / 180);
		ctx.rect(0, 0, w, h);
		ctx.fillStyle = "white";
		ctx.fill();

		ctx.beginPath();
		ctx.moveTo(startX, startY);
		ctx.lineTo(startX, startY + (15 - 0.9) * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 三分線
		ctx.beginPath();
		ctx.moveTo(startX, startY);
		ctx.lineTo(startX + 14 * METER_RATIO, startY);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 15 * METER_RATIO);
		ctx.lineTo(startX, startY + 15 * METER_RATIO);
		ctx.lineTo(startX, startY + (15 - 0.9) * METER_RATIO);
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + (15 - 0.9) * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(90 - degree),
			degToRad(-90 + degree),
			true
		);
		ctx.lineTo(startX, startY + 0.9 * METER_RATIO);
		ctx.lineTo(startX, startY);

		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 半場線
		ctx.beginPath();
		ctx.moveTo(startX + 14 * METER_RATIO, startY);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 15 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 籃框
		ctx.drawImage(hoop, startX + 1.2 * METER_RATIO - 40, startY + 7.5 * METER_RATIO - 40, 80, 80);

		// 得分區 1
		ctx.beginPath();
		ctx.moveTo(startX, startY);
		ctx.lineTo(startX, startY + 0.9 * METER_RATIO);
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 0.9 * METER_RATIO); // 往右
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY); // 往下
		ctx.lineTo(startX, startY);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 2
		ctx.beginPath();
		ctx.moveTo(startX + endLineToArc * METER_RATIO, startY); // 左下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 0.9 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(-90 + degree),
			degToRad(-15),
			false
		);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 4.17 * METER_RATIO); // 往右
		ctx.lineTo(startX + 14 * METER_RATIO, startY); // 往下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 3
		ctx.beginPath();
		ctx.moveTo(startX + 8.095 * METER_RATIO, startY + 9.25 * METER_RATIO); // 左下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(15),
			degToRad(-15),
			true
		);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 4.17 * METER_RATIO); // 左下往上
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 10.83 * METER_RATIO); // 往右
		ctx.lineTo(startX + 8.095 * METER_RATIO, startY + 9.25 * METER_RATIO); // 往下
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 4
		ctx.beginPath();
		ctx.moveTo(startX + endLineToArc * METER_RATIO, startY + 15 * METER_RATIO); // 左下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 14.1 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(90 - degree),
			degToRad(15),
			true
		);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 10.83 * METER_RATIO); // 往右
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 15 * METER_RATIO); // 往下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 15 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 5
		ctx.beginPath();
		ctx.moveTo(startX, startY + 14.1 * METER_RATIO); // 左下
		ctx.lineTo(startX, startY + 15 * METER_RATIO); // 左下往上
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 15 * METER_RATIO); // 往右
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 14.1 * METER_RATIO); // 往下
		ctx.lineTo(startX, startY + 14.1 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 6
		ctx.beginPath();
		ctx.moveTo(startX, startY + 0.9 * METER_RATIO);
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 0.9 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(-90 + degree),
			degToRad(-54),
			false
		);
		ctx.lineTo(startX + 4.445 * METER_RATIO, startY + 3.56 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(-54),
			degToRad(-90 - 18.36),
			true
		);
		ctx.lineTo(startX, startY + 0.9 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 7
		ctx.beginPath();
		ctx.moveTo(startX + 4.445 * METER_RATIO, startY + 3.56 * METER_RATIO);
		ctx.lineTo(startX + 5.544 * METER_RATIO, startY + 2.04 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(-54),
			degToRad(-18),
			false
		);
		ctx.lineTo(startX + 6.215 * METER_RATIO, startY + 5.992 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(-18),
			degToRad(-54),
			true
		);
		ctx.lineTo(startX + 4.445 * METER_RATIO, startY + 3.56 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 8
		ctx.beginPath();
		ctx.moveTo(startX + 6.215 * METER_RATIO, startY + 5.992 * METER_RATIO); // 左下
		ctx.lineTo(startX + 7.994 * METER_RATIO, startY + 5.414 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(-18),
			degToRad(18),
			false
		); // 往右
		ctx.lineTo(startX + 6.215 * METER_RATIO, startY + 9.007 * METER_RATIO); // 往下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(18),
			degToRad(-18),
			true
		);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 9
		ctx.beginPath();
		ctx.moveTo(startX + 6.215 * METER_RATIO, startY + 9.007 * METER_RATIO); // 左下
		ctx.lineTo(startX + 7.994 * METER_RATIO, startY + 9.586 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(18),
			degToRad(54),
			false
		); // 往右
		ctx.lineTo(startX + 4.445 * METER_RATIO, startY + 11.44 * METER_RATIO); // 往下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(54),
			degToRad(18),
			true
		);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 10
		ctx.beginPath();
		ctx.moveTo(startX, startY + 14.1 * METER_RATIO); // 左下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 14.1 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(90 - degree),
			degToRad(54),
			true
		); // 往右
		ctx.lineTo(startX + 4.445 * METER_RATIO, startY + 11.44 * METER_RATIO); // 往下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(54),
			degToRad(90 + 18.36),
			false
		);
		ctx.lineTo(startX, startY + 14.1 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 11
		ctx.beginPath();
		ctx.moveTo(startX, startY + 5.05 * METER_RATIO); // 左下
		ctx.lineTo(startX + 5.8 * METER_RATIO, startY + 5.05 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(-30),
			degToRad(-90 - 18.36),
			true
		); // 往右
		ctx.lineTo(startX, startY + 5.05 * METER_RATIO); // 往下
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 12
		ctx.beginPath();
		ctx.moveTo(startX + 2.073 * METER_RATIO, startY + 5.05 * METER_RATIO);
		ctx.lineTo(startX + 5.8 * METER_RATIO, startY + 5.05 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(-30),
			degToRad(30),
			false
		); // 往右
		ctx.lineTo(startX + 2.073 * METER_RATIO, startY + 9.95 * METER_RATIO); // 往下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			2.5 * METER_RATIO,
			degToRad(90 - 11.48),
			degToRad(-90 + 11.48),
			true
		);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 13
		ctx.beginPath();
		ctx.moveTo(startX, startY + 9.95 * METER_RATIO); // 左下
		ctx.lineTo(startX + 5.8 * METER_RATIO, startY + 9.95 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(30),
			degToRad(90 + 18.36),
			false
		); // 往右
		ctx.lineTo(startX, startY + 9.95 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 14
		ctx.beginPath();
		ctx.moveTo(startX, startY + 5.05 * METER_RATIO);
		ctx.lineTo(startX + 2.073 * METER_RATIO, startY + 5.05 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			2.5 * METER_RATIO,
			degToRad(-90 + 11.48),
			degToRad(90 - 11.48),
			false
		);
		ctx.lineTo(startX, startY + 9.95 * METER_RATIO);
		ctx.lineTo(startX, startY + 5.05 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		var made = document.getElementById("made");
		var miss = document.getElementById("miss");

		$.getJSON(playerShootingChartJSON, function (data) {
			$.each(data, function (i, gameRecord) {
				if (gameRecord.eventName == "score" && gameRecord.offenseBasket == 0) {
					ctx.drawImage(made, gameRecord.eventPointX - 128 / 4, h - gameRecord.eventPointY - 128 / 4, 128 / 2, 128 / 2);
				}
				if (gameRecord.eventName == "miss" && gameRecord.offenseBasket == 0) {
					ctx.drawImage(miss, gameRecord.eventPointX - 128 / 4, h - gameRecord.eventPointY - 128 / 4, 128 / 2, 128 / 2);
				}
				if (gameRecord.eventName == "score" && gameRecord.offenseBasket == 1) {
					ctx.drawImage(made, w - gameRecord.eventPointX - 128 / 4, gameRecord.eventPointY - 128 / 4, 128 / 2, 128 / 2);
				}
				if (gameRecord.eventName == "miss" && gameRecord.offenseBasket == 1) {
					ctx.drawImage(miss, w - gameRecord.eventPointX - 128 / 4, gameRecord.eventPointY - 128 / 4, 128 / 2, 128 / 2);
				}
			});
		});
		ctx.restore();
	}

	function drawPercentageCourt(courtId, playerShootingChartJSON) {
		var c = $(courtId);
		var ctx = c[0].getContext("2d");
		var hoop = document.getElementById("hoop");

		var startX = 40,
			startY = 40,
			METER_RATIO = 85;
		var endLineToArc = 1.415 + 1.575;
		var degree = 12.101;

		// 轉90度
		ctx.translate(h, 0);
		ctx.rotate((90 * Math.PI) / 180);
		ctx.rect(0, 0, w, h);
		ctx.fillStyle = "white";
		ctx.fill();

		ctx.beginPath();
		ctx.moveTo(startX, startY);
		ctx.lineTo(startX, startY + (15 - 0.9) * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 三分線
		ctx.beginPath();
		ctx.moveTo(startX, startY);
		ctx.lineTo(startX + 14 * METER_RATIO, startY);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 15 * METER_RATIO);
		ctx.lineTo(startX, startY + 15 * METER_RATIO);
		ctx.lineTo(startX, startY + (15 - 0.9) * METER_RATIO);
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + (15 - 0.9) * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(90 - degree),
			degToRad(-90 + degree),
			true
		);
		ctx.lineTo(startX, startY + 0.9 * METER_RATIO);
		ctx.lineTo(startX, startY);

		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 半場線
		ctx.beginPath();
		ctx.moveTo(startX + 14 * METER_RATIO, startY);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 15 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 籃框
		ctx.drawImage(hoop, startX + 1.2 * METER_RATIO - 40, startY + 7.5 * METER_RATIO - 40, 80, 80);

		// 得分區 1
		ctx.beginPath();
		ctx.moveTo(startX, startY);
		ctx.lineTo(startX, startY + 0.9 * METER_RATIO);
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 0.9 * METER_RATIO); // 往右
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY); // 往下
		ctx.lineTo(startX, startY);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 2
		ctx.beginPath();
		ctx.moveTo(startX + endLineToArc * METER_RATIO, startY); // 左下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 0.9 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(-90 + degree),
			degToRad(-15),
			false
		);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 4.17 * METER_RATIO); // 往右
		ctx.lineTo(startX + 14 * METER_RATIO, startY); // 往下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 3
		ctx.beginPath();
		ctx.moveTo(startX + 8.095 * METER_RATIO, startY + 9.25 * METER_RATIO); // 左下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(15),
			degToRad(-15),
			true
		);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 4.17 * METER_RATIO); // 左下往上
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 10.83 * METER_RATIO); // 往右
		ctx.lineTo(startX + 8.095 * METER_RATIO, startY + 9.25 * METER_RATIO); // 往下
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 4
		ctx.beginPath();
		ctx.moveTo(startX + endLineToArc * METER_RATIO, startY + 15 * METER_RATIO); // 左下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 14.1 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(90 - degree),
			degToRad(15),
			true
		);
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 10.83 * METER_RATIO); // 往右
		ctx.lineTo(startX + 14 * METER_RATIO, startY + 15 * METER_RATIO); // 往下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 15 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 5
		ctx.beginPath();
		ctx.moveTo(startX, startY + 14.1 * METER_RATIO); // 左下
		ctx.lineTo(startX, startY + 15 * METER_RATIO); // 左下往上
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 15 * METER_RATIO); // 往右
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 14.1 * METER_RATIO); // 往下
		ctx.lineTo(startX, startY + 14.1 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 6
		ctx.beginPath();
		ctx.moveTo(startX, startY + 0.9 * METER_RATIO);
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 0.9 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(-90 + degree),
			degToRad(-54),
			false
		);
		ctx.lineTo(startX + 4.445 * METER_RATIO, startY + 3.56 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(-54),
			degToRad(-90 - 18.36),
			true
		);
		ctx.lineTo(startX, startY + 0.9 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 7
		ctx.beginPath();
		ctx.moveTo(startX + 4.445 * METER_RATIO, startY + 3.56 * METER_RATIO);
		ctx.lineTo(startX + 5.544 * METER_RATIO, startY + 2.04 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(-54),
			degToRad(-18),
			false
		);
		ctx.lineTo(startX + 6.215 * METER_RATIO, startY + 5.992 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(-18),
			degToRad(-54),
			true
		);
		ctx.lineTo(startX + 4.445 * METER_RATIO, startY + 3.56 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 8
		ctx.beginPath();
		ctx.moveTo(startX + 6.215 * METER_RATIO, startY + 5.992 * METER_RATIO); // 左下
		ctx.lineTo(startX + 7.994 * METER_RATIO, startY + 5.414 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(-18),
			degToRad(18),
			false
		); // 往右
		ctx.lineTo(startX + 6.215 * METER_RATIO, startY + 9.007 * METER_RATIO); // 往下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(18),
			degToRad(-18),
			true
		);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 9
		ctx.beginPath();
		ctx.moveTo(startX + 6.215 * METER_RATIO, startY + 9.007 * METER_RATIO); // 左下
		ctx.lineTo(startX + 7.994 * METER_RATIO, startY + 9.586 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(18),
			degToRad(54),
			false
		); // 往右
		ctx.lineTo(startX + 4.445 * METER_RATIO, startY + 11.44 * METER_RATIO); // 往下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(54),
			degToRad(18),
			true
		);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 10
		ctx.beginPath();
		ctx.moveTo(startX, startY + 14.1 * METER_RATIO); // 左下
		ctx.lineTo(startX + endLineToArc * METER_RATIO, startY + 14.1 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			6.75 * METER_RATIO,
			degToRad(90 - degree),
			degToRad(54),
			true
		); // 往右
		ctx.lineTo(startX + 4.445 * METER_RATIO, startY + 11.44 * METER_RATIO); // 往下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(54),
			degToRad(90 + 18.36),
			false
		);
		ctx.lineTo(startX, startY + 14.1 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 11
		ctx.beginPath();
		ctx.moveTo(startX, startY + 5.05 * METER_RATIO); // 左下
		ctx.lineTo(startX + 5.8 * METER_RATIO, startY + 5.05 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(-30),
			degToRad(-90 - 18.36),
			true
		); // 往右
		ctx.lineTo(startX, startY + 5.05 * METER_RATIO); // 往下
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 12
		ctx.beginPath();
		ctx.moveTo(startX + 2.073 * METER_RATIO, startY + 5.05 * METER_RATIO);
		ctx.lineTo(startX + 5.8 * METER_RATIO, startY + 5.05 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(-30),
			degToRad(30),
			false
		); // 往右
		ctx.lineTo(startX + 2.073 * METER_RATIO, startY + 9.95 * METER_RATIO); // 往下
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			2.5 * METER_RATIO,
			degToRad(90 - 11.48),
			degToRad(-90 + 11.48),
			true
		);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 13
		ctx.beginPath();
		ctx.moveTo(startX, startY + 9.95 * METER_RATIO); // 左下
		ctx.lineTo(startX + 5.8 * METER_RATIO, startY + 9.95 * METER_RATIO); // 左下往上
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			4.88 * METER_RATIO,
			degToRad(30),
			degToRad(90 + 18.36),
			false
		); // 往右
		ctx.lineTo(startX, startY + 9.95 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		// 得分區 14
		ctx.beginPath();
		ctx.moveTo(startX, startY + 5.05 * METER_RATIO);
		ctx.lineTo(startX + 2.073 * METER_RATIO, startY + 5.05 * METER_RATIO);
		ctx.arc(
			startX + 1.575 * METER_RATIO,
			startY + 7.5 * METER_RATIO,
			2.5 * METER_RATIO,
			degToRad(-90 + 11.48),
			degToRad(90 - 11.48),
			false
		);
		ctx.lineTo(startX, startY + 9.95 * METER_RATIO);
		ctx.lineTo(startX, startY + 5.05 * METER_RATIO);
		ctx.strokeStyle = "black";
		ctx.lineWidth = 5;
		ctx.stroke();

		var pointArea1 = new Object();
		pointArea1.made = 0;
		pointArea1.miss = 0;
		var pointArea2 = new Object();
		pointArea2.made = 0;
		pointArea2.miss = 0;
		var pointArea3 = new Object();
		pointArea3.made = 0;
		pointArea3.miss = 0;
		var pointArea4 = new Object();
		pointArea4.made = 0;
		pointArea4.miss = 0;
		var pointArea5 = new Object();
		pointArea5.made = 0;
		pointArea5.miss = 0;
		var pointArea6 = new Object();
		pointArea6.made = 0;
		pointArea6.miss = 0;
		var pointArea7 = new Object();
		pointArea7.made = 0;
		pointArea7.miss = 0;
		var pointArea8 = new Object();
		pointArea8.made = 0;
		pointArea8.miss = 0;
		var pointArea9 = new Object();
		pointArea9.made = 0;
		pointArea9.miss = 0;
		var pointArea10 = new Object();
		pointArea10.made = 0;
		pointArea10.miss = 0;
		var pointArea11 = new Object();
		pointArea11.made = 0;
		pointArea11.miss = 0;
		var pointArea12 = new Object();
		pointArea12.made = 0;
		pointArea12.miss = 0;
		var pointArea13 = new Object();
		pointArea13.made = 0;
		pointArea13.miss = 0;
		var pointArea14 = new Object();
		pointArea14.made = 0;
		pointArea14.miss = 0;

		$.getJSON(playerShootingChartJSON, function (data) {
			$.each(data, function (i, gameRecord) {
				if (gameRecord.eventName == "score") {
					switch (gameRecord.scoringArea) {
						case 1:
							pointArea1.made += 1;
							break;
						case 2:
							pointArea2.made += 1;
							break;
						case 3:
							pointArea3.made += 1;
							break;
						case 4:
							pointArea4.made += 1;
							break;
						case 5:
							pointArea5.made += 1;
							break;
						case 6:
							pointArea6.made += 1;
							break;
						case 7:
							pointArea7.made += 1;
							break;
						case 8:
							pointArea8.made += 1;
							break;
						case 9:
							pointArea9.made += 1;
							break;
						case 10:
							pointArea10.made += 1;
							break;
						case 11:
							pointArea11.made += 1;
							break;
						case 12:
							pointArea12.made += 1;
							break;
						case 13:
							pointArea13.made += 1;
							break;
						case 14:
							pointArea14.made += 1;
							break;
					}
				}
				if (gameRecord.eventName == "miss") {
					switch (gameRecord.scoringArea) {
						case 1:
							pointArea1.miss += 1;
							break;
						case 2:
							pointArea2.miss += 1;
							break;
						case 3:
							pointArea3.miss += 1;
							break;
						case 4:
							pointArea4.miss += 1;
							break;
						case 5:
							pointArea5.miss += 1;
							break;
						case 6:
							pointArea6.miss += 1;
							break;
						case 7:
							pointArea7.miss += 1;
							break;
						case 8:
							pointArea8.miss += 1;
							break;
						case 9:
							pointArea9.miss += 1;
							break;
						case 10:
							pointArea10.miss += 1;
							break;
						case 11:
							pointArea11.miss += 1;
							break;
						case 12:
							pointArea12.miss += 1;
							break;
						case 13:
							pointArea13.miss += 1;
							break;
						case 14:
							pointArea14.miss += 1;
							break;
					}
				}
			});
			ctx.save();
			ctx.translate(0, h);
			ctx.rotate(-Math.PI / 2);
			ctx.fillStyle = "black";
			ctx.font = "30px Arial";
			var area1Percentage = Math.round((pointArea1.made / (pointArea1.miss + pointArea1.made)) * 100);
			if (isNaN(area1Percentage)) {
				area1Percentage = 0;
			}
			ctx.fillText(area1Percentage + "%", startX + 0.25 * METER_RATIO, startY + 1.5 * METER_RATIO);
			ctx.fillText(
				pointArea1.made + "/" + (pointArea1.miss + pointArea1.made),
				startX + 0.23 * METER_RATIO,
				startY + 2 * METER_RATIO
			);
			var area2Percentage = Math.round((pointArea2.made / (pointArea2.miss + pointArea2.made)) * 100);
			if (isNaN(area2Percentage)) {
				area2Percentage = 0;
			}
			ctx.fillText(area2Percentage + "%", startX + 2 * METER_RATIO, startY + 10 * METER_RATIO);
			ctx.fillText(
				pointArea2.made + "/" + (pointArea2.miss + pointArea2.made),
				startX + 1.9 * METER_RATIO,
				startY + 10.5 * METER_RATIO
			);
			var area3Percentage = Math.round((pointArea3.made / (pointArea3.miss + pointArea3.made)) * 100);
			if (isNaN(area3Percentage)) {
				area3Percentage = 0;
			}
			ctx.fillText(area3Percentage + "%", startX + 7.5 * METER_RATIO, startY + 12 * METER_RATIO);
			ctx.fillText(
				pointArea3.made + "/" + (pointArea3.miss + pointArea3.made),
				startX + 7.4 * METER_RATIO,
				startY + 12.5 * METER_RATIO
			);
			var area4Percentage = Math.round((pointArea4.made / (pointArea4.miss + pointArea4.made)) * 100);
			if (isNaN(area4Percentage)) {
				area4Percentage = 0;
			}
			ctx.fillText(area4Percentage + "%", startX + 13 * METER_RATIO, startY + 10 * METER_RATIO);
			ctx.fillText(
				pointArea4.made + "/" + (pointArea4.miss + pointArea4.made),
				startX + 12.9 * METER_RATIO,
				startY + 10.5 * METER_RATIO
			);
			var area5Percentage = Math.round((pointArea5.made / (pointArea5.miss + pointArea5.made)) * 100);
			if (isNaN(area5Percentage)) {
				area5Percentage = 0;
			}
			ctx.fillText(area5Percentage + "%", startX + 14.35 * METER_RATIO, startY + 1.5 * METER_RATIO);
			ctx.fillText(
				pointArea5.made + "/" + (pointArea5.miss + pointArea5.made),
				startX + 14.3 * METER_RATIO,
				startY + 2 * METER_RATIO
			);
			var area6Percentage = Math.round((pointArea6.made / (pointArea6.miss + pointArea6.made)) * 100);
			if (isNaN(area6Percentage)) {
				area6Percentage = 0;
			}
			ctx.fillText(area6Percentage + "%", startX + 1.5 * METER_RATIO, startY + 3 * METER_RATIO);
			ctx.fillText(
				pointArea6.made + "/" + (pointArea6.miss + pointArea6.made),
				startX + 1.4 * METER_RATIO,
				startY + 3.5 * METER_RATIO
			);
			var area7Percentage = Math.round((pointArea7.made / (pointArea7.miss + pointArea7.made)) * 100);
			if (isNaN(area7Percentage)) {
				area7Percentage = 0;
			}
			ctx.fillText(area7Percentage + "%", startX + 4 * METER_RATIO, startY + 6.5 * METER_RATIO);
			ctx.fillText(
				pointArea7.made + "/" + (pointArea7.miss + pointArea7.made),
				startX + 3.9 * METER_RATIO,
				startY + 7 * METER_RATIO
			);
			var area8Percentage = Math.round((pointArea8.made / (pointArea8.miss + pointArea8.made)) * 100);
			if (isNaN(area8Percentage)) {
				area8Percentage = 0;
			}
			ctx.fillText(area8Percentage + "%", startX + 7.5 * METER_RATIO, startY + 7.5 * METER_RATIO);
			ctx.fillText(
				pointArea8.made + "/" + (pointArea8.miss + pointArea8.made),
				startX + 7.4 * METER_RATIO,
				startY + 8 * METER_RATIO
			);
			var area9Percentage = Math.round((pointArea9.made / (pointArea9.miss + pointArea9.made)) * 100);
			if (isNaN(area9Percentage)) {
				area9Percentage = 0;
			}
			ctx.fillText(area9Percentage + "%", startX + 11 * METER_RATIO, startY + 6.5 * METER_RATIO);
			ctx.fillText(
				pointArea9.made + "/" + (pointArea9.miss + pointArea9.made),
				startX + 10.9 * METER_RATIO,
				startY + 7 * METER_RATIO
			);
			var area10Percentage = Math.round((pointArea10.made / (pointArea10.miss + pointArea10.made)) * 100);
			if (isNaN(area10Percentage)) {
				area10Percentage = 0;
			}
			ctx.fillText(area10Percentage + "%", startX + 13 * METER_RATIO, startY + 3 * METER_RATIO);
			ctx.fillText(
				pointArea10.made + "/" + (pointArea10.miss + pointArea10.made),
				startX + 12.9 * METER_RATIO,
				startY + 3.5 * METER_RATIO
			);
			var area11Percentage = Math.round((pointArea11.made / (pointArea11.miss + pointArea11.made)) * 100);
			if (isNaN(area11Percentage)) {
				area11Percentage = 0;
			}
			ctx.fillText(area11Percentage + "%", startX + 3.5 * METER_RATIO, startY + 2.5 * METER_RATIO);
			ctx.fillText(
				pointArea11.made + "/" + (pointArea11.miss + pointArea11.made),
				startX + 3.4 * METER_RATIO,
				startY + 3 * METER_RATIO
			);
			var area12Percentage = Math.round((pointArea12.made / (pointArea12.miss + pointArea12.made)) * 100);
			if (isNaN(area12Percentage)) {
				area12Percentage = 0;
			}
			ctx.fillText(area12Percentage + "%", startX + 7.5 * METER_RATIO, startY + 5.5 * METER_RATIO);
			ctx.fillText(
				pointArea12.made + "/" + (pointArea12.miss + pointArea12.made),
				startX + 7.4 * METER_RATIO,
				startY + 6 * METER_RATIO
			);
			var area13Percentage = Math.round((pointArea13.made / (pointArea13.miss + pointArea13.made)) * 100);
			if (isNaN(area13Percentage)) {
				area13Percentage = 0;
			}
			ctx.fillText(area13Percentage + "%", startX + 11 * METER_RATIO, startY + 2.5 * METER_RATIO);
			ctx.fillText(
				pointArea13.made + "/" + (pointArea13.miss + pointArea13.made),
				startX + 10.9 * METER_RATIO,
				startY + 3 * METER_RATIO
			);
			var area14Percentage = Math.round((pointArea14.made / (pointArea14.miss + pointArea14.made)) * 100);
			if (isNaN(area14Percentage)) {
				area14Percentage = 0;
			}
			ctx.fillText(area14Percentage + "%", startX + 7.5 * METER_RATIO, startY + 2.5 * METER_RATIO);
			ctx.fillText(
				pointArea14.made + "/" + (pointArea14.miss + pointArea14.made),
				startX + 7.4 * METER_RATIO,
				startY + 3 * METER_RATIO
			);
			ctx.restore();
		});
	}
});
